Class: Google::Apis::CivicinfoV2::CivicinfoApiprotosV2ElectionsQueryResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/civicinfo_v2/classes.rb,
lib/google/apis/civicinfo_v2/representations.rb,
lib/google/apis/civicinfo_v2/representations.rb

Overview

The list of elections available for this version of the API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CivicinfoApiprotosV2ElectionsQueryResponse

Returns a new instance of CivicinfoApiprotosV2ElectionsQueryResponse.



126
127
128
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 126

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#electionsArray<Google::Apis::CivicinfoV2::CivicinfoSchemaV2Election>

A list of available elections Corresponds to the JSON property elections



118
119
120
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 118

def elections
  @elections
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "civicinfo# electionsQueryResponse". Corresponds to the JSON property kind

Returns:

  • (String)


124
125
126
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 124

def kind
  @kind
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



131
132
133
134
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 131

def update!(**args)
  @elections = args[:elections] if args.key?(:elections)
  @kind = args[:kind] if args.key?(:kind)
end