Class: Google::Apis::CivicinfoV2::CivicinfoSchemaV2AdministrativeBody

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/civicinfo_v2/classes.rb,
lib/google/apis/civicinfo_v2/representations.rb,
lib/google/apis/civicinfo_v2/representations.rb

Overview

Information about an election administrative body (e.g. County Board of Elections).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CivicinfoSchemaV2AdministrativeBody

Returns a new instance of CivicinfoSchemaV2AdministrativeBody.



365
366
367
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 365

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#absentee_voting_info_urlString

A URL provided by this administrative body for information on absentee voting. Corresponds to the JSON property absenteeVotingInfoUrl

Returns:

  • (String)


286
287
288
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 286

def absentee_voting_info_url
  @absentee_voting_info_url
end

#ballot_info_urlString

A URL provided by this administrative body to give contest information to the voter. Corresponds to the JSON property ballotInfoUrl

Returns:

  • (String)


292
293
294
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 292

def ballot_info_url
  @ballot_info_url
end

#correspondence_addressGoogle::Apis::CivicinfoV2::CivicinfoSchemaV2SimpleAddressType

A simple representation of an address. Corresponds to the JSON property correspondenceAddress



297
298
299
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 297

def correspondence_address
  @correspondence_address
end

#election_info_urlString

A URL provided by this administrative body for looking up general election information. Corresponds to the JSON property electionInfoUrl

Returns:

  • (String)


303
304
305
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 303

def election_info_url
  @election_info_url
end

#election_notice_textString

A last minute or emergency notification text provided by this administrative body. Corresponds to the JSON property electionNoticeText

Returns:

  • (String)


309
310
311
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 309

def election_notice_text
  @election_notice_text
end

#election_notice_urlString

A URL provided by this administrative body for additional information related to the last minute or emergency notification. Corresponds to the JSON property electionNoticeUrl

Returns:

  • (String)


315
316
317
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 315

def election_notice_url
  @election_notice_url
end

#election_officialsArray<Google::Apis::CivicinfoV2::CivicinfoSchemaV2ElectionOfficial>

The election officials for this election administrative body. Corresponds to the JSON property electionOfficials



320
321
322
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 320

def election_officials
  @election_officials
end

#election_registration_confirmation_urlString

A URL provided by this administrative body for confirming that the voter is registered to vote. Corresponds to the JSON property electionRegistrationConfirmationUrl

Returns:

  • (String)


326
327
328
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 326

def election_registration_confirmation_url
  @election_registration_confirmation_url
end

#election_registration_urlString

A URL provided by this administrative body for looking up how to register to vote. Corresponds to the JSON property electionRegistrationUrl

Returns:

  • (String)


332
333
334
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 332

def election_registration_url
  @election_registration_url
end

#election_rules_urlString

A URL provided by this administrative body describing election rules to the voter. Corresponds to the JSON property electionRulesUrl

Returns:

  • (String)


338
339
340
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 338

def election_rules_url
  @election_rules_url
end

#hours_of_operationString

A description of the hours of operation for this administrative body. Corresponds to the JSON property hoursOfOperation

Returns:

  • (String)


343
344
345
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 343

def hours_of_operation
  @hours_of_operation
end

#nameString

The name of this election administrative body. Corresponds to the JSON property name

Returns:

  • (String)


348
349
350
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 348

def name
  @name
end

#physical_addressGoogle::Apis::CivicinfoV2::CivicinfoSchemaV2SimpleAddressType

A simple representation of an address. Corresponds to the JSON property physicalAddress



353
354
355
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 353

def physical_address
  @physical_address
end

#voter_servicesArray<String>

A description of the services this administrative body may provide. Corresponds to the JSON property voter_services

Returns:

  • (Array<String>)


358
359
360
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 358

def voter_services
  @voter_services
end

#voting_location_finder_urlString

A URL provided by this administrative body for looking up where to vote. Corresponds to the JSON property votingLocationFinderUrl

Returns:

  • (String)


363
364
365
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 363

def voting_location_finder_url
  @voting_location_finder_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 370

def update!(**args)
  @absentee_voting_info_url = args[:absentee_voting_info_url] if args.key?(:absentee_voting_info_url)
  @ballot_info_url = args[:ballot_info_url] if args.key?(:ballot_info_url)
  @correspondence_address = args[:correspondence_address] if args.key?(:correspondence_address)
  @election_info_url = args[:election_info_url] if args.key?(:election_info_url)
  @election_notice_text = args[:election_notice_text] if args.key?(:election_notice_text)
  @election_notice_url = args[:election_notice_url] if args.key?(:election_notice_url)
  @election_officials = args[:election_officials] if args.key?(:election_officials)
  @election_registration_confirmation_url = args[:election_registration_confirmation_url] if args.key?(:election_registration_confirmation_url)
  @election_registration_url = args[:election_registration_url] if args.key?(:election_registration_url)
  @election_rules_url = args[:election_rules_url] if args.key?(:election_rules_url)
  @hours_of_operation = args[:hours_of_operation] if args.key?(:hours_of_operation)
  @name = args[:name] if args.key?(:name)
  @physical_address = args[:physical_address] if args.key?(:physical_address)
  @voter_services = args[:voter_services] if args.key?(:voter_services)
  @voting_location_finder_url = args[:voting_location_finder_url] if args.key?(:voting_location_finder_url)
end