Class: Google::Apis::CivicinfoV2::CivicinfoSchemaV2Channel
- Inherits:
-
Object
- Object
- Google::Apis::CivicinfoV2::CivicinfoSchemaV2Channel
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/civicinfo_v2/classes.rb,
lib/google/apis/civicinfo_v2/representations.rb,
lib/google/apis/civicinfo_v2/representations.rb
Overview
A social media or web channel for a candidate.
Instance Attribute Summary collapse
-
#id ⇒ String
The unique public identifier for the candidate's channel.
-
#type ⇒ String
The type of channel.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CivicinfoSchemaV2Channel
constructor
A new instance of CivicinfoSchemaV2Channel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CivicinfoSchemaV2Channel
Returns a new instance of CivicinfoSchemaV2Channel.
468 469 470 |
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 468 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
The unique public identifier for the candidate's channel.
Corresponds to the JSON property id
459 460 461 |
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 459 def id @id end |
#type ⇒ String
The type of channel. The following is a list of types of channels, but is not
exhaustive. More channel types may be added at a later time. One of:
GooglePlus, YouTube, Facebook, Twitter
Corresponds to the JSON property type
466 467 468 |
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 466 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
473 474 475 476 |
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 473 def update!(**args) @id = args[:id] if args.key?(:id) @type = args[:type] if args.key?(:type) end |