Class: Google::Apis::CivicinfoV2::CivicinfoSchemaV2Contest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/civicinfo_v2/classes.rb,
lib/google/apis/civicinfo_v2/representations.rb,
lib/google/apis/civicinfo_v2/representations.rb

Overview

Information about a contest that appears on a voter's ballot.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CivicinfoSchemaV2Contest

Returns a new instance of CivicinfoSchemaV2Contest.



625
626
627
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 625

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ballot_placementFixnum

A number specifying the position of this contest on the voter's ballot. Corresponds to the JSON property ballotPlacement

Returns:

  • (Fixnum)


486
487
488
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 486

def ballot_placement
  @ballot_placement
end

#ballot_titleString

The official title on the ballot for this contest, only where available. Corresponds to the JSON property ballotTitle

Returns:

  • (String)


491
492
493
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 491

def ballot_title
  @ballot_title
end

#candidatesArray<Google::Apis::CivicinfoV2::CivicinfoSchemaV2Candidate>

The candidate choices for this contest. Corresponds to the JSON property candidates



496
497
498
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 496

def candidates
  @candidates
end

#districtGoogle::Apis::CivicinfoV2::CivicinfoSchemaV2ElectoralDistrict

Describes the geographic scope of a contest. Corresponds to the JSON property district



501
502
503
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 501

def district
  @district
end

#electorate_specificationsString

A description of any additional eligibility requirements for voting in this contest. Corresponds to the JSON property electorateSpecifications

Returns:

  • (String)


507
508
509
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 507

def electorate_specifications
  @electorate_specifications
end

#levelArray<String>

The levels of government of the office for this contest. There may be more than one in cases where a jurisdiction effectively acts at two different levels of government; for example, the mayor of the District of Columbia acts at "locality" level, but also effectively at both "administrative-area-2" and " administrative-area-1". Corresponds to the JSON property level

Returns:

  • (Array<String>)


516
517
518
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 516

def level
  @level
end

#number_electedFixnum

The number of candidates that will be elected to office in this contest. Corresponds to the JSON property numberElected

Returns:

  • (Fixnum)


521
522
523
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 521

def number_elected
  @number_elected
end

#number_voting_forFixnum

The number of candidates that a voter may vote for in this contest. Corresponds to the JSON property numberVotingFor

Returns:

  • (Fixnum)


526
527
528
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 526

def number_voting_for
  @number_voting_for
end

#officeString

The name of the office for this contest. Corresponds to the JSON property office

Returns:

  • (String)


531
532
533
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 531

def office
  @office
end

#primary_partiesArray<String>

If this is a partisan election, the name of the party/parties it is for. Corresponds to the JSON property primaryParties

Returns:

  • (Array<String>)


536
537
538
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 536

def primary_parties
  @primary_parties
end

#referendum_ballot_responsesArray<String>

The set of ballot responses for the referendum. A ballot response represents a line on the ballot. Common examples might include "yes" or "no" for referenda. This field is only populated for contests of type 'Referendum'. Corresponds to the JSON property referendumBallotResponses

Returns:

  • (Array<String>)


543
544
545
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 543

def referendum_ballot_responses
  @referendum_ballot_responses
end

#referendum_briefString

Specifies a short summary of the referendum that is typically on the ballot below the title but above the text. This field is only populated for contests of type 'Referendum'. Corresponds to the JSON property referendumBrief

Returns:

  • (String)


550
551
552
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 550

def referendum_brief
  @referendum_brief
end

#referendum_con_statementString

A statement in opposition to the referendum. It does not necessarily appear on the ballot. This field is only populated for contests of type 'Referendum'. Corresponds to the JSON property referendumConStatement

Returns:

  • (String)


556
557
558
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 556

def referendum_con_statement
  @referendum_con_statement
end

#referendum_effect_of_abstainString

Specifies what effect abstaining (not voting) on the proposition will have (i. e. whether abstaining is considered a vote against it). This field is only populated for contests of type 'Referendum'. Corresponds to the JSON property referendumEffectOfAbstain

Returns:

  • (String)


563
564
565
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 563

def referendum_effect_of_abstain
  @referendum_effect_of_abstain
end

#referendum_passage_thresholdString

The threshold of votes that the referendum needs in order to pass, e.g. "two- thirds". This field is only populated for contests of type 'Referendum'. Corresponds to the JSON property referendumPassageThreshold

Returns:

  • (String)


569
570
571
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 569

def referendum_passage_threshold
  @referendum_passage_threshold
end

#referendum_pro_statementString

A statement in favor of the referendum. It does not necessarily appear on the ballot. This field is only populated for contests of type 'Referendum'. Corresponds to the JSON property referendumProStatement

Returns:

  • (String)


575
576
577
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 575

def referendum_pro_statement
  @referendum_pro_statement
end

#referendum_subtitleString

A brief description of the referendum. This field is only populated for contests of type 'Referendum'. Corresponds to the JSON property referendumSubtitle

Returns:

  • (String)


581
582
583
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 581

def referendum_subtitle
  @referendum_subtitle
end

#referendum_textString

The full text of the referendum. This field is only populated for contests of type 'Referendum'. Corresponds to the JSON property referendumText

Returns:

  • (String)


587
588
589
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 587

def referendum_text
  @referendum_text
end

#referendum_titleString

The title of the referendum (e.g. 'Proposition 42'). This field is only populated for contests of type 'Referendum'. Corresponds to the JSON property referendumTitle

Returns:

  • (String)


593
594
595
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 593

def referendum_title
  @referendum_title
end

#referendum_urlString

A link to the referendum. This field is only populated for contests of type ' Referendum'. Corresponds to the JSON property referendumUrl

Returns:

  • (String)


599
600
601
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 599

def referendum_url
  @referendum_url
end

#rolesArray<String>

The roles which this office fulfills. Corresponds to the JSON property roles

Returns:

  • (Array<String>)


604
605
606
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 604

def roles
  @roles
end

#sourcesArray<Google::Apis::CivicinfoV2::CivicinfoSchemaV2Source>

A list of sources for this contest. If multiple sources are listed, the data has been aggregated from those sources. Corresponds to the JSON property sources



610
611
612
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 610

def sources
  @sources
end

#specialString

"Yes" or "No" depending on whether this a contest being held outside the normal election cycle. Corresponds to the JSON property special

Returns:

  • (String)


616
617
618
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 616

def special
  @special
end

#typeString

The type of contest. Usually this will be 'General', 'Primary', or 'Run-off' for contests with candidates. For referenda this will be 'Referendum'. For Retention contests this will typically be 'Retention'. Corresponds to the JSON property type

Returns:

  • (String)


623
624
625
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 623

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 630

def update!(**args)
  @ballot_placement = args[:ballot_placement] if args.key?(:ballot_placement)
  @ballot_title = args[:ballot_title] if args.key?(:ballot_title)
  @candidates = args[:candidates] if args.key?(:candidates)
  @district = args[:district] if args.key?(:district)
  @electorate_specifications = args[:electorate_specifications] if args.key?(:electorate_specifications)
  @level = args[:level] if args.key?(:level)
  @number_elected = args[:number_elected] if args.key?(:number_elected)
  @number_voting_for = args[:number_voting_for] if args.key?(:number_voting_for)
  @office = args[:office] if args.key?(:office)
  @primary_parties = args[:primary_parties] if args.key?(:primary_parties)
  @referendum_ballot_responses = args[:referendum_ballot_responses] if args.key?(:referendum_ballot_responses)
  @referendum_brief = args[:referendum_brief] if args.key?(:referendum_brief)
  @referendum_con_statement = args[:referendum_con_statement] if args.key?(:referendum_con_statement)
  @referendum_effect_of_abstain = args[:referendum_effect_of_abstain] if args.key?(:referendum_effect_of_abstain)
  @referendum_passage_threshold = args[:referendum_passage_threshold] if args.key?(:referendum_passage_threshold)
  @referendum_pro_statement = args[:referendum_pro_statement] if args.key?(:referendum_pro_statement)
  @referendum_subtitle = args[:referendum_subtitle] if args.key?(:referendum_subtitle)
  @referendum_text = args[:referendum_text] if args.key?(:referendum_text)
  @referendum_title = args[:referendum_title] if args.key?(:referendum_title)
  @referendum_url = args[:referendum_url] if args.key?(:referendum_url)
  @roles = args[:roles] if args.key?(:roles)
  @sources = args[:sources] if args.key?(:sources)
  @special = args[:special] if args.key?(:special)
  @type = args[:type] if args.key?(:type)
end