Class: Google::Apis::CivicinfoV2::CivicinfoSchemaV2Source

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/civicinfo_v2/classes.rb,
lib/google/apis/civicinfo_v2/representations.rb,
lib/google/apis/civicinfo_v2/representations.rb

Overview

Contains information about the data source for the element containing it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CivicinfoSchemaV2Source

Returns a new instance of CivicinfoSchemaV2Source.



1081
1082
1083
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 1081

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The name of the data source. Corresponds to the JSON property name

Returns:

  • (String)


1073
1074
1075
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 1073

def name
  @name
end

#officialBoolean Also known as: official?

Whether this data comes from an official government source. Corresponds to the JSON property official

Returns:

  • (Boolean)


1078
1079
1080
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 1078

def official
  @official
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1086
1087
1088
1089
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 1086

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @official = args[:official] if args.key?(:official)
end