Module: Google::Apis::CivicinfoV2
- Defined in:
- lib/google/apis/civicinfo_v2.rb,
lib/google/apis/civicinfo_v2/classes.rb,
lib/google/apis/civicinfo_v2/service.rb,
lib/google/apis/civicinfo_v2/gem_version.rb,
lib/google/apis/civicinfo_v2/representations.rb
Overview
Google Civic Information API
Provides polling places, early vote locations, contest data, election officials, and government representatives for U.S. residential addresses.
Defined Under Namespace
Classes: CivicInfoService, CivicinfoApiprotosV2DivisionByAddressResponse, CivicinfoApiprotosV2DivisionSearchResponse, CivicinfoApiprotosV2DivisionSearchResult, CivicinfoApiprotosV2ElectionsQueryResponse, CivicinfoApiprotosV2VoterInfoResponse, CivicinfoSchemaV2AdministrationRegion, CivicinfoSchemaV2AdministrativeBody, CivicinfoSchemaV2Candidate, CivicinfoSchemaV2Channel, CivicinfoSchemaV2Contest, CivicinfoSchemaV2Election, CivicinfoSchemaV2ElectionOfficial, CivicinfoSchemaV2ElectoralDistrict, CivicinfoSchemaV2GeographicDivision, CivicinfoSchemaV2PollingLocation, CivicinfoSchemaV2Precinct, CivicinfoSchemaV2SimpleAddressType, CivicinfoSchemaV2Source
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-civicinfo_v2 gem
"0.28.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.19.0"- REVISION =
Revision of the discovery document this client was generated from
"20250708"- VERSION =
Version of the Google Civic Information API this client connects to. This is NOT the gem version.
'V2'