Class: Google::Apis::CivicinfoV2::CivicinfoSchemaV2PollingLocation
- Inherits:
-
Object
- Object
- Google::Apis::CivicinfoV2::CivicinfoSchemaV2PollingLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/civicinfo_v2/classes.rb,
lib/google/apis/civicinfo_v2/representations.rb,
lib/google/apis/civicinfo_v2/representations.rb
Overview
A location where a voter can vote. This may be an early vote site, an election day voting location, or a drop off location for a completed ballot.
Instance Attribute Summary collapse
-
#address ⇒ Google::Apis::CivicinfoV2::CivicinfoSchemaV2SimpleAddressType
A simple representation of an address.
-
#end_date ⇒ String
The last date that this early vote site or drop off location may be used.
-
#latitude ⇒ Float
Latitude of the location, in degrees north of the equator.
-
#longitude ⇒ Float
Longitude of the location, in degrees east of the Prime Meridian.
-
#name ⇒ String
The name of the early vote site or drop off location.
-
#notes ⇒ String
Notes about this location (e.g. accessibility ramp or entrance to use).
-
#polling_hours ⇒ String
A description of when this location is open.
-
#sources ⇒ Array<Google::Apis::CivicinfoV2::CivicinfoSchemaV2Source>
A list of sources for this location.
-
#start_date ⇒ String
The first date that this early vote site or drop off location may be used.
-
#voter_services ⇒ String
The services provided by this early vote site or drop off location.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CivicinfoSchemaV2PollingLocation
constructor
A new instance of CivicinfoSchemaV2PollingLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CivicinfoSchemaV2PollingLocation
Returns a new instance of CivicinfoSchemaV2PollingLocation.
884 885 886 |
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 884 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ Google::Apis::CivicinfoV2::CivicinfoSchemaV2SimpleAddressType
A simple representation of an address.
Corresponds to the JSON property address
830 831 832 |
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 830 def address @address end |
#end_date ⇒ String
The last date that this early vote site or drop off location may be used. This
field is not populated for polling locations.
Corresponds to the JSON property endDate
836 837 838 |
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 836 def end_date @end_date end |
#latitude ⇒ Float
Latitude of the location, in degrees north of the equator. Note this field may
not be available for some locations.
Corresponds to the JSON property latitude
842 843 844 |
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 842 def latitude @latitude end |
#longitude ⇒ Float
Longitude of the location, in degrees east of the Prime Meridian. Note this
field may not be available for some locations.
Corresponds to the JSON property longitude
848 849 850 |
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 848 def longitude @longitude end |
#name ⇒ String
The name of the early vote site or drop off location. This field is not
populated for polling locations.
Corresponds to the JSON property name
854 855 856 |
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 854 def name @name end |
#notes ⇒ String
Notes about this location (e.g. accessibility ramp or entrance to use).
Corresponds to the JSON property notes
859 860 861 |
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 859 def notes @notes end |
#polling_hours ⇒ String
A description of when this location is open.
Corresponds to the JSON property pollingHours
864 865 866 |
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 864 def polling_hours @polling_hours end |
#sources ⇒ Array<Google::Apis::CivicinfoV2::CivicinfoSchemaV2Source>
A list of sources for this location. If multiple sources are listed the data
has been aggregated from those sources.
Corresponds to the JSON property sources
870 871 872 |
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 870 def sources @sources end |
#start_date ⇒ String
The first date that this early vote site or drop off location may be used.
This field is not populated for polling locations.
Corresponds to the JSON property startDate
876 877 878 |
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 876 def start_date @start_date end |
#voter_services ⇒ String
The services provided by this early vote site or drop off location. This field
is not populated for polling locations.
Corresponds to the JSON property voterServices
882 883 884 |
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 882 def voter_services @voter_services end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
889 890 891 892 893 894 895 896 897 898 899 900 |
# File 'lib/google/apis/civicinfo_v2/classes.rb', line 889 def update!(**args) @address = args[:address] if args.key?(:address) @end_date = args[:end_date] if args.key?(:end_date) @latitude = args[:latitude] if args.key?(:latitude) @longitude = args[:longitude] if args.key?(:longitude) @name = args[:name] if args.key?(:name) @notes = args[:notes] if args.key?(:notes) @polling_hours = args[:polling_hours] if args.key?(:polling_hours) @sources = args[:sources] if args.key?(:sources) @start_date = args[:start_date] if args.key?(:start_date) @voter_services = args[:voter_services] if args.key?(:voter_services) end |